==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/el_gr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_fields_map'] = 'Αυτή η ενότητα σάς επιτρέπει να μετονομάσετε το όνομα των πεδίων του συμβάντος που ενεργοποιείται σε ένα προσαρμοσμένο όνομα πριν από την αποστολή τους στο callback. Τα υποπεδία πρέπει να διαχωρίζονται με τελεία (π.χ. vars.status). Για να δείτε μια λίστα με όλα τα πεδία που υποστηρίζονται από κάθε ένα από τα συμβάντα, μπορείτε να ελέγξετε τον ακόλουθο <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">σύνδεσμο</a>.';
$lang['AdminMain.edit.field_editsubmit'] = 'Επεξεργασία Webhook';
$lang['AdminMain.edit.field_add_field'] = 'Προσθήκη πεδίου';
$lang['AdminMain.edit.field_method'] = 'Μέθοδος';
$lang['AdminMain.edit.field_type'] = 'Callback';
$lang['AdminMain.edit.field_event'] = 'Εκδήλωση';
$lang['AdminMain.edit.field_callback'] = 'Callback';
$lang['AdminMain.edit.option_delete'] = 'Διαγραφή';
$lang['AdminMain.edit.heading_options'] = 'Επιλογές';
$lang['AdminMain.edit.heading_parameter'] = 'Νέο πεδίο';
$lang['AdminMain.edit.heading_field'] = 'Αρχικό πεδίο';
$lang['AdminMain.edit.heading_fields_map'] = 'Χάρτης πεδίων';
$lang['AdminMain.edit.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.edit.boxtitle_editwebhook'] = 'Επεξεργασία Webhook';
$lang['AdminMain.add.text_fields_map'] = 'Αυτή η ενότητα σάς επιτρέπει να μετονομάσετε το όνομα των πεδίων του συμβάντος που ενεργοποιείται σε ένα προσαρμοσμένο όνομα πριν από την αποστολή τους στο callback. Τα υποπεδία πρέπει να διαχωρίζονται με τελεία (π.χ. vars.status). Για να δείτε μια λίστα με όλα τα πεδία που υποστηρίζονται από κάθε ένα από τα συμβάντα, μπορείτε να ελέγξετε τον ακόλουθο <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">σύνδεσμο</a>.';
$lang['AdminMain.add.field_addsubmit'] = 'Προσθήκη Webhook';
$lang['AdminMain.add.field_add_field'] = 'Προσθήκη πεδίου';
$lang['AdminMain.add.field_method'] = 'Μέθοδος';
$lang['AdminMain.add.field_type'] = 'Callback';
$lang['AdminMain.add.field_event'] = 'Εκδήλωση';
$lang['AdminMain.add.field_callback'] = 'Callback';
$lang['AdminMain.add.option_delete'] = 'Διαγραφή';
$lang['AdminMain.add.heading_options'] = 'Επιλογές';
$lang['AdminMain.add.heading_parameter'] = 'Νέο πεδίο';
$lang['AdminMain.add.heading_field'] = 'Αρχικό πεδίο';
$lang['AdminMain.add.heading_fields_map'] = 'Χάρτης πεδίων';
$lang['AdminMain.add.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.add.boxtitle_addwebhook'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.no_results'] = 'Δεν υπάρχουν διαθέσιμα webhooks.';
$lang['AdminMain.index.text_description_incoming'] = 'Λαμβάνει ένα αίτημα HTTP και ενεργοποιεί ένα συμβάν στο σύστημα χρησιμοποιώντας τις παραμέτρους που λαμβάνονται στο αίτημα. Το αίτημα μπορεί να ληφθεί με τη χρήση GET, POST ή JSON.';
$lang['AdminMain.index.text_description_outgoing'] = 'Αποστέλλει ένα αίτημα HTTP σε μια διεύθυνση URL όταν ενεργοποιείται ένα συμβάν. Το αίτημα μπορεί να σταλεί με τη χρήση GET, POST ή JSON.';
$lang['AdminMain.index.option_delete'] = 'Διαγραφή';
$lang['AdminMain.index.option_edit'] = 'Επεξεργασία';
$lang['AdminMain.index.heading_options'] = 'Επιλογές';
$lang['AdminMain.index.heading_method'] = 'Μέθοδος';
$lang['AdminMain.index.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.index.heading_callback'] = 'Callback';
$lang['AdminMain.index.boxtitle_webhooks'] = 'Webhooks';
$lang['AdminMain.index.categorylink_addwebhook'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.category_outgoing'] = 'Εξερχόμενο';
$lang['AdminMain.index.category_incoming'] = 'Εισερχόμενο';
$lang['AdminMain.index.page_title_edit'] = 'Επεξεργασία Webhook';
$lang['AdminMain.index.page_title_add'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.page_title_index'] = 'Webhooks';
$lang['AdminMain.modal.delete_text'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτό το webhook;';
$lang['AdminMain.!success.webhook_deleted'] = 'Το webhook διαγράφηκε με επιτυχία!';
$lang['AdminMain.!success.webhook_updated'] = 'Το webhook ενημερώθηκε με επιτυχία!';
$lang['AdminMain.!success.webhook_added'] = 'Το webhook προστέθηκε με επιτυχία!';
$lang['AdminMain.!tooltip.callback'] = 'Το callback αντιπροσωπεύει τον τόπο αποστολής ή λήψης του αιτήματος, για τα εξερχόμενα webhooks πρέπει να είναι μια διεύθυνση URL και για τα εισερχόμενα webhooks πρέπει να είναι το όνομα της διεύθυνσης URL όπου θα ληφθεί το αίτημα. π.χ. http://blesta.com/plugin/webhooks/trigger/index/[Callback Name].';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/el_gr/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.el_gr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.edit.text_fields_map'] = 'Αυτή η ενότητα σάς επιτρέπει να μετονομάσετε το όνομα των πεδίων του συμβάντος που ενεργοποιείται σε ένα προσαρμοσμένο όνομα πριν από την αποστολή τους στο callback. Τα υποπεδία πρέπει να διαχωρίζονται με τελεία (π.χ. vars.status). Για να δείτε μια λίστα με όλα τα πεδία που υποστηρίζονται από κάθε ένα από τα συμβάντα, μπορείτε να ελέγξετε τον ακόλουθο <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">σύνδεσμο</a>.';
$lang['AdminMain.edit.field_editsubmit'] = 'Επεξεργασία Webhook';
$lang['AdminMain.edit.field_add_field'] = 'Προσθήκη πεδίου';
$lang['AdminMain.edit.field_method'] = 'Μέθοδος';
$lang['AdminMain.edit.field_type'] = 'Callback';
$lang['AdminMain.edit.field_event'] = 'Εκδήλωση';
$lang['AdminMain.edit.field_callback'] = 'Callback';
$lang['AdminMain.edit.option_delete'] = 'Διαγραφή';
$lang['AdminMain.edit.heading_options'] = 'Επιλογές';
$lang['AdminMain.edit.heading_parameter'] = 'Νέο πεδίο';
$lang['AdminMain.edit.heading_field'] = 'Αρχικό πεδίο';
$lang['AdminMain.edit.heading_fields_map'] = 'Χάρτης πεδίων';
$lang['AdminMain.edit.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.edit.boxtitle_editwebhook'] = 'Επεξεργασία Webhook';
$lang['AdminMain.add.text_fields_map'] = 'Αυτή η ενότητα σάς επιτρέπει να μετονομάσετε το όνομα των πεδίων του συμβάντος που ενεργοποιείται σε ένα προσαρμοσμένο όνομα πριν από την αποστολή τους στο callback. Τα υποπεδία πρέπει να διαχωρίζονται με τελεία (π.χ. vars.status). Για να δείτε μια λίστα με όλα τα πεδία που υποστηρίζονται από κάθε ένα από τα συμβάντα, μπορείτε να ελέγξετε τον ακόλουθο <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">σύνδεσμο</a>.';
$lang['AdminMain.add.field_addsubmit'] = 'Προσθήκη Webhook';
$lang['AdminMain.add.field_add_field'] = 'Προσθήκη πεδίου';
$lang['AdminMain.add.field_method'] = 'Μέθοδος';
$lang['AdminMain.add.field_type'] = 'Callback';
$lang['AdminMain.add.field_event'] = 'Εκδήλωση';
$lang['AdminMain.add.field_callback'] = 'Callback';
$lang['AdminMain.add.option_delete'] = 'Διαγραφή';
$lang['AdminMain.add.heading_options'] = 'Επιλογές';
$lang['AdminMain.add.heading_parameter'] = 'Νέο πεδίο';
$lang['AdminMain.add.heading_field'] = 'Αρχικό πεδίο';
$lang['AdminMain.add.heading_fields_map'] = 'Χάρτης πεδίων';
$lang['AdminMain.add.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.add.boxtitle_addwebhook'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.no_results'] = 'Δεν υπάρχουν διαθέσιμα webhooks.';
$lang['AdminMain.index.text_description_incoming'] = 'Λαμβάνει ένα αίτημα HTTP και ενεργοποιεί ένα συμβάν στο σύστημα χρησιμοποιώντας τις παραμέτρους που λαμβάνονται στο αίτημα. Το αίτημα μπορεί να ληφθεί με τη χρήση GET, POST ή JSON.';
$lang['AdminMain.index.text_description_outgoing'] = 'Αποστέλλει ένα αίτημα HTTP σε μια διεύθυνση URL όταν ενεργοποιείται ένα συμβάν. Το αίτημα μπορεί να σταλεί χρησιμοποιώντας GET, POST, PUT ή JSON.';
$lang['AdminMain.index.option_delete'] = 'Διαγραφή';
$lang['AdminMain.index.option_edit'] = 'Επεξεργασία';
$lang['AdminMain.index.heading_options'] = 'Επιλογές';
$lang['AdminMain.index.heading_method'] = 'Μέθοδος';
$lang['AdminMain.index.heading_event'] = 'Εκδήλωση';
$lang['AdminMain.index.heading_callback'] = 'Callback';
$lang['AdminMain.index.boxtitle_webhooks'] = 'Webhooks';
$lang['AdminMain.index.categorylink_addwebhook'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.category_outgoing'] = 'Εξερχόμενο';
$lang['AdminMain.index.category_incoming'] = 'Εισερχόμενο';
$lang['AdminMain.index.page_title_edit'] = 'Επεξεργασία Webhook';
$lang['AdminMain.index.page_title_add'] = 'Προσθήκη Webhook';
$lang['AdminMain.index.page_title_index'] = 'Webhooks';
$lang['AdminMain.modal.delete_text'] = 'Είστε σίγουροι ότι θέλετε να διαγράψετε αυτό το webhook;';
$lang['AdminMain.!success.webhook_deleted'] = 'Το webhook διαγράφηκε με επιτυχία!';
$lang['AdminMain.!success.webhook_updated'] = 'Το webhook ενημερώθηκε με επιτυχία!';
$lang['AdminMain.!success.webhook_added'] = 'Το webhook προστέθηκε με επιτυχία!';
$lang['AdminMain.!tooltip.callback'] = 'Το callback αντιπροσωπεύει τον τόπο αποστολής ή λήψης του αιτήματος, για τα εξερχόμενα webhooks πρέπει να είναι μια διεύθυνση URL και για τα εισερχόμενα webhooks πρέπει να είναι το όνομα της διεύθυνσης URL όπου θα ληφθεί το αίτημα. π.χ. http://blesta.com/plugin/webhooks/trigger/index/[Callback Name].';
$lang['AdminMain.edit.field_cancel'] = 'Ακύρωση';
$lang['AdminMain.add.field_cancel'] = 'Ακύρωση';
